==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/msg_list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="msg_list.php?<?php echo $message_box;?>=" method="post" name="message">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "msg_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php if (!isset($homepage)) { ?>
						<a href="<?php echo $page_name;?>?homepage=1" class="txt_sub_menu"><?php echo $lang['href_homepage_set'];?></a><br />
						<?php  } else{ ?>
						<?php echo $lang['txt_homepage_current'];?><br />
						<?php  } ?>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
			
		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="5" class="txt_title" align="right">
						<?php echo $lang['section_messages'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($messages[0])) {
				foreach($messages as $key => $i):
				?>
				<tr>
					<td valign="top">
						<?php
						if ($i['message_status'] == $message_status_read) {
						    echo "<a href=\"msg_item.php?message_id=" . $i['message_id'] . "\"><img src='" . $templatePath . "img/openned_mail.png' vspace='2' border='0'></a><br />";
						}
						else if ($i['message_status'] == $message_status_unread) {
							echo "<a href=\"msg_item.php?message_id=" . $i['message_id'] . "\"><img src='" . $templatePath . "img/unopenned_mail.png' vspace='2' border='0'></a><br />";
						}
						?>

					</td>
					<td valign="top">
						<?php echo $i['user_nic'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['message_create_datetime'];?><br />
						<a href="msg_item.php?message_id=<?php echo $i['message_id'];?>">
						<?php echo $i['message_subject'];?>
						</a><br />
					</td>
					<td valign="top">
						<?php echo strlen($i['message_body']);?><br />
					</td>
					<td  valign="top" align="right">
						<input type="checkbox" name="message_id[]" value="<?php echo $i['message_id'];?>" /><br />
					</td>
				</tr>

				<tr>
					<td colspan="5">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="5">
						<?php echo $lang['err_no_messages'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td align="right" class="txt_footer">
						<br /><img src="<?php echo $templatePath;?>img/unopenned_mail.png" alt="" />&nbsp;<?php echo $lang['txt_unopened'];?>&nbsp;&nbsp;<img src="<?php echo $templatePath;?>img/openned_mail.png" alt="" />&nbsp;<?php echo $lang['txt_opened'];?><br />
					</td>
				</tr>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_message_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer" colspan="3">
						<?php echo $lang['txt_message_statistics'];?><br />
					</td>
				</tr>
				<?php
				$percentage_used = floor((100/$message_statistics['total_size_allowed']) * $message_statistics['total_size']);
				if ($percentage_used > 100) {
				    $percentage_used = 100;
				}
				?>
				<tr>
					<td colspan="3">
						<table border="0" cellspacing="0" cellpadding="0" width="100%">
							<tr>
								<?php if($percentage_used>0) {?>
								<td width="<?php echo $percentage_used;?>%" class="bg1">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" alt="" /><br />
								</td>
								<?php }?>
								<td class="bg2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" alt="" /><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td class="txt_footer" align="right" colspan="3">
						<?php echo $percentage_used;?>&#37; used<br />
					</td>
				</tr>
				<tr>
					<td>
						<table width="100%" cellpadding="1" cellspacing="0" border="0">
			    			<tr>
								<td class="txt_footer">
									<b><?php echo $lang['txt_box'];?></b><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $lang['txt_messages'];?></b><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $lang['txt_size'];?></b><br />
								</td>
							</tr>

							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_box_in'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['in_box_messages'];?>&nbsp;(<?php echo $message_statistics['unread'];?>)<br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['in_box_size'];?><br />
								</td>
							</tr>
							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_box_out'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['out_box_messages'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['out_box_size'];?><br />
								</td>
							</tr>
							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_box_save'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['save_box_messages'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['save_box_size'];?><br />
								</td>
							</tr>
							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_totals'];?><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $message_statistics['total_messages'];?></b><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $message_statistics['total_size'];?></b><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<?php if ($messages) { ?>
				<tr>
					<td valign="top" class="txt_footer">
						<?php echo $lang['txt_delete_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" align="right">
						<input type="button" onClick="checkFormBoxes('message', 'message_id', 'check');" value="<?php echo $lang['sub_select_all'];?>" class="formInput" />&nbsp;&nbsp;
						<input type="submit" name="delete_messages" value="<?php echo $lang['sub_delete'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php if ($message_box != "save_box") { ?>
				<tr>
					<td valign="top" class="txt_footer">
						<?php echo $lang['txt_move_to_save_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" align="right">
						<input type="submit" name="move_to_save" value="<?php echo $lang['sub_move_to_save'];?>" class="formInput" /><br />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer">
						<?php echo $lang['txt_mess-status_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" align="right">
						<input type="submit" name="set_read_messages" value="<?php echo $lang['sub_read'];?>" class="formInput" />&nbsp;&nbsp;&nbsp;
						<input type="submit" name="set_unread_messages" value="<?php echo $lang['sub_unread'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php  } ?>
				<?php  } ?>
			</table>
		</td>
	</tr>
</table>
</form>

<script language="javascript">
<!--

function checkFormBoxes() { //task is check or uncheck

	var form = document.message.elements['message_id[]']
	
	var state = true;
	
	if (form[0].checked == true) {
		state = false;
	}
	

	for (var i=0; i < form.length; i++) {
		form[i].checked = state;

	}
}

//-->
</script>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/msg_list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="msg_list.php?<?php echo $message_box;?>=" method="post" name="message">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "msg_menu.inc.tpl.php";
			?>
			
			<?php if ($messages) { ?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				
				<tr>
					<td valign="top">
						<?php echo $lang['txt_delete_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" align="right">
						<input type="button" onClick="checkFormBoxes('message', 'message_id', 'check');" value="<?php echo $lang['sub_select_all'];?>" class="formInput" />&nbsp;&nbsp;
						<input type="submit" name="delete_messages" value="<?php echo $lang['sub_delete'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php if ($message_box != "save_box") { ?>
				<tr>
					<td valign="top">
						<?php echo $lang['txt_move_to_save_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" align="right">
						<input type="submit" name="move_to_save" value="<?php echo $lang['sub_move_to_save'];?>" class="formInput" /><br />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $lang['txt_mess-status_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" align="right">
						<input type="submit" name="set_read_messages" value="<?php echo $lang['sub_read'];?>" class="formInput" />&nbsp;&nbsp;&nbsp;
						<input type="submit" name="set_unread_messages" value="<?php echo $lang['sub_unread'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php  } ?>
			</table>
			<?php  } ?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
			
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_messages'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php
						if (isset($messages)) {
						?>
						<table border="0" cellspacing="2" cellpadding="4" width="100%" class="picture">
							<?php
							foreach($messages as $key => $i):
							?>
							<tr>
								<td valign="middle">
									<?php
									if ($i['message_status'] == $message_status_read) {
									    echo "<a href=\"msg_item.php?message_id=" . $i['message_id'] . "\"><img src='" . $templatePath . "img/openned_mail.png' vspace='2' border='0'></a>&nbsp;<br />";
									}
									else if ($i['message_status'] == $message_status_unread) {
										echo "<a href=\"msg_item.php?message_id=" . $i['message_id'] . "\"><img src='" . $templatePath . "img/unopenned_mail.png' vspace='2' border='0'></a>&nbsp;<br />";
									}
									?>

								</td>
								<td valign="middle" class="bg3" align="center">
									<?php echo $i['profile_nic'];?><br />
								</td>
								<td valign="middle" class="bg4">
									<?php echo $i['message_create_datetime'];?><br />
									<a href="msg_item.php?message_id=<?php echo $i['message_id'];?>"><?php echo $i['message_subject'];?></a><br />
								</td>
								<td valign="middle" class="bg4" align="center">
									<?php echo strlen($i['message_body']);?><br />
								</td>
								<td  valign="middle" align="right" class="bg2" width="1">
									<input type="checkbox" name="message_id[]" value="<?php echo $i['message_id'];?>" /><br />
								</td>
							</tr>
							<?php
							endforeach;
							?>
						</table>
					</td>
				</tr>
				<?php
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_messages'];?><br />
					</td>
				</tr>
				<?php }?>
				<tr>
					<td align="right" class="txt_footer">
						<br /><img src="<?php echo $templatePath;?>img/unopenned_mail.png" alt="" />&nbsp;<?php echo $lang['txt_unopened'];?>&nbsp;&nbsp;<img src="<?php echo $templatePath;?>img/openned_mail.png" alt="" />&nbsp;<?php echo $lang['txt_opened'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_message_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
			    			<tr>
								<td class="bg2">
									<span class="txt_footer">
									<b><?php echo $lang['txt_box'];?></b><br />
									</span>
								</td>
								<td class="bg2">
									<span class="txt_footer">
									<?php echo $lang['txt_box_in'];?><br />
									</span>
								</td>
								<td class="bg2">
									<span class="txt_footer">
									<?php echo $lang['txt_box_out'];?><br />
									</span>
								</td>
								<td class="bg2">
									<span class="txt_footer">
									<?php echo $lang['txt_box_save'];?><br />
									</span>
								</td>
								<td class="bg2">
									<span class="txt_footer">
									<?php echo $lang['txt_totals'];?><br />
									</span>
								</td>
							</tr>
							
							<tr>
								<td class="bg3">
									<span class="txt_footer">
									<b><?php echo $lang['txt_messages'];?></b><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['in_box_messages'];?>&nbsp;(<?php echo $message_statistics['unread'];?>)<br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['out_box_messages'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['save_box_messages'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<b><?php echo $message_statistics['total_messages'];?></b><br />
									</span>
								</td>
							</tr>
							
							<tr>
								<td class="bg3">
									<span class="txt_footer">
									<b><?php echo $lang['txt_size'];?></b><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['in_box_size'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['out_box_size'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['save_box_size'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<b><?php echo $message_statistics['total_size'];?></b><br />
									</span>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				$percentage_used = floor((100/$message_statistics['total_size_allowed']) * $message_statistics['total_size']);
				if ($percentage_used > 100) {
				    $percentage_used = 100;
				}
				?>
				<tr>
					<td colspan="3">
						<table border="0" cellspacing="2" cellpadding="0" width="100%" class="picture">
							<tr>
								<?php if($percentage_used>0) {?>
								<td width="<?php echo $percentage_used;?>%" class="bg1">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" alt="" /><br />
								</td>
								<?php }?>
								<td class="bg2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" alt="" /><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td class="txt_footer" align="right" colspan="3">
						<?php echo $percentage_used;?>&#37; used<br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</form>

<script language="javascript">
<!--

function checkFormBoxes() { //task is check or uncheck

	var form = document.message.elements['message_id[]']
	
	var state = true;
	
	if (form[0].checked == true) {
		state = false;
	}
	

	for (var i=0; i < form.length; i++) {
		form[i].checked = state;

	}
}

//-->
</script>
